Release 
-------

  - update moke.core.__version__
  - update setup.py version
  - update CHANGELOG.rst
  - update doc/source/conf.py
  - regenerate docs/html
  - push docs/html to gh-pages
  - push moke to github
  - python setup.py sdist upload
    
  
TODO
----

  - add version support to the moke executable
